@@ -5,9 +5,11 @@ obtained from radheef.mv.
 """
 
 import sqlite3
+import pkg_resources
 
 
-def _db_connect(db_path="./data/dhivehi_nlp.db"):
+def _db_connect():
+    db_path = pkg_resources.resource_filename("dhivehi_nlp", "data/dhivehi_nlp.db")
     con = sqlite3.connect(db_path)
     return con
 
